# Hash-keys based crypto


Usages:
`protectycrypto.get_keys()` - Returning all UTF-8 characters
`protectycrypto.get_hash_keys(version)` - Returning hash keys (version - count of characters in key)
`protectycrypto.encode(text, hash_keys)` - Encoding
`protectycrypto.decoded(text, hash_keys)` - Decoding"# protectycrypto" 
